Package 'ojoverse'

Title: All the Open Justice Oklahoma R Tools in One Place
Description: This package is a collection of all the Open Justice Oklahoma R tools. It is meant to be used for interactive workflows, not as a dependency for other packages. Fully inspired, and mostly written, by developers of the [{tidyverse}](https://github.com/tidyverse/tidyverse) package.
Authors: Brancen Gregory [aut, cre]
Maintainer: Brancen Gregory <[email protected]>
License: GPL (>= 3)
Version: 0.4.1
Built: 2026-06-06 10:08:56 UTC
Source: https://github.com/openjusticeok/ojoverse

Help Index


Conflicts between the ojoverse and other packages

Description

This function lists all the conflicts between packages in the ojoverse and other packages that you have loaded.

Usage

ojoverse_conflicts(only = NULL)

Arguments

only

Set this to a character vector to restrict to conflicts only with these packages.

Examples

ojoverse_conflicts()

List all ojoverse dependencies

Description

List all ojoverse dependencies

Usage

ojoverse_dependencies(recursive = FALSE, repos = getOption("repos"))

Arguments

recursive

If TRUE, will also list all dependencies of ojoverse packages.

repos

The repositories to use to check for updates. Defaults to getOption("repos").


List all packages in the ojoverse

Description

List all packages in the ojoverse

Usage

ojoverse_packages(include_self = TRUE)

Arguments

include_self

Include ojoverse in the list?

Examples

ojoverse_packages()

Get a status report on the ojoverse

Description

This function gives a quick overview of the versions of R and RStudio as well as all ojoverse packages. It's primarily designed to help you get a quick idea of what's going on when you're helping someone else debug a problem.

Usage

ojoverse_status()

Update ojoverse packages

Description

This will check to see if all ojoverse packages (and optionally, their dependencies) are up-to-date, and will install after an interactive confirmation.

Usage

ojoverse_update(recursive = FALSE, repos = getOption("repos"))

Arguments

recursive

If TRUE, will also list all dependencies of ojoverse packages.

repos

The repositories to use to check for updates. Defaults to getOption("repos").

Examples

## Not run: 
ojoverse_update()

## End(Not run)