| Title: | All the Open Justice Oklahoma R Tools in One Place |
|---|---|
| Description: | This package is a collection of all the Open Justice Oklahoma R tools. It is meant to be used for interactive workflows, not as a dependency for other packages. Fully inspired, and mostly written, by developers of the [{tidyverse}](https://github.com/tidyverse/tidyverse) package. |
| Authors: | Brancen Gregory [aut, cre] |
| Maintainer: | Brancen Gregory <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.4.1 |
| Built: | 2026-06-06 10:08:56 UTC |
| Source: | https://github.com/openjusticeok/ojoverse |
This function lists all the conflicts between packages in the ojoverse and other packages that you have loaded.
ojoverse_conflicts(only = NULL)ojoverse_conflicts(only = NULL)
only |
Set this to a character vector to restrict to conflicts only with these packages. |
ojoverse_conflicts()ojoverse_conflicts()
List all ojoverse dependencies
ojoverse_dependencies(recursive = FALSE, repos = getOption("repos"))ojoverse_dependencies(recursive = FALSE, repos = getOption("repos"))
recursive |
If |
repos |
The repositories to use to check for updates.
Defaults to |
cli::ansi_strip() to get rid of the colors.Use cli::ansi_strip() to get rid of the colors.
ojoverse_logo(unicode = cli::is_utf8_output())ojoverse_logo(unicode = cli::is_utf8_output())
unicode |
Whether to use Unicode symbols. Default is |
ojoverse_logo()ojoverse_logo()
List all packages in the ojoverse
ojoverse_packages(include_self = TRUE)ojoverse_packages(include_self = TRUE)
include_self |
Include ojoverse in the list? |
ojoverse_packages()ojoverse_packages()
This function gives a quick overview of the versions of R and RStudio as well as all ojoverse packages. It's primarily designed to help you get a quick idea of what's going on when you're helping someone else debug a problem.
ojoverse_status()ojoverse_status()
This will check to see if all ojoverse packages (and optionally, their dependencies) are up-to-date, and will install after an interactive confirmation.
ojoverse_update(recursive = FALSE, repos = getOption("repos"))ojoverse_update(recursive = FALSE, repos = getOption("repos"))
recursive |
If |
repos |
The repositories to use to check for updates.
Defaults to |
## Not run: ojoverse_update() ## End(Not run)## Not run: ojoverse_update() ## End(Not run)